/*******************************************************************************
* File Name: GLCDPWM_1_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "GLCDPWM_1.h"

static GLCDPWM_1_backupStruct GLCDPWM_1_backup;


/*******************************************************************************
* Function Name: GLCDPWM_1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_1_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void GLCDPWM_1_SaveConfig(void) 
{

    #if(!GLCDPWM_1_UsingFixedFunction)
        #if(!GLCDPWM_1_PWMModeIsCenterAligned)
            GLCDPWM_1_backup.PWMPeriod = GLCDPWM_1_ReadPeriod();
        #endif /* (!GLCDPWM_1_PWMModeIsCenterAligned) */
        GLCDPWM_1_backup.PWMUdb = GLCDPWM_1_ReadCounter();
        #if (GLCDPWM_1_UseStatus)
            GLCDPWM_1_backup.InterruptMaskValue = GLCDPWM_1_STATUS_MASK;
        #endif /* (GLCDPWM_1_UseStatus) */

        #if(GLCDPWM_1_DeadBandMode == GLCDPWM_1__B_PWM__DBM_256_CLOCKS || \
            GLCDPWM_1_DeadBandMode == GLCDPWM_1__B_PWM__DBM_2_4_CLOCKS)
            GLCDPWM_1_backup.PWMdeadBandValue = GLCDPWM_1_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(GLCDPWM_1_KillModeMinTime)
             GLCDPWM_1_backup.PWMKillCounterPeriod = GLCDPWM_1_ReadKillTime();
        #endif /* (GLCDPWM_1_KillModeMinTime) */

        #if(GLCDPWM_1_UseControl)
            GLCDPWM_1_backup.PWMControlRegister = GLCDPWM_1_ReadControlRegister();
        #endif /* (GLCDPWM_1_UseControl) */
    #endif  /* (!GLCDPWM_1_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: GLCDPWM_1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_1_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void GLCDPWM_1_RestoreConfig(void) 
{
        #if(!GLCDPWM_1_UsingFixedFunction)
            #if(!GLCDPWM_1_PWMModeIsCenterAligned)
                GLCDPWM_1_WritePeriod(GLCDPWM_1_backup.PWMPeriod);
            #endif /* (!GLCDPWM_1_PWMModeIsCenterAligned) */

            GLCDPWM_1_WriteCounter(GLCDPWM_1_backup.PWMUdb);

            #if (GLCDPWM_1_UseStatus)
                GLCDPWM_1_STATUS_MASK = GLCDPWM_1_backup.InterruptMaskValue;
            #endif /* (GLCDPWM_1_UseStatus) */

            #if(GLCDPWM_1_DeadBandMode == GLCDPWM_1__B_PWM__DBM_256_CLOCKS || \
                GLCDPWM_1_DeadBandMode == GLCDPWM_1__B_PWM__DBM_2_4_CLOCKS)
                GLCDPWM_1_WriteDeadTime(GLCDPWM_1_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(GLCDPWM_1_KillModeMinTime)
                GLCDPWM_1_WriteKillTime(GLCDPWM_1_backup.PWMKillCounterPeriod);
            #endif /* (GLCDPWM_1_KillModeMinTime) */

            #if(GLCDPWM_1_UseControl)
                GLCDPWM_1_WriteControlRegister(GLCDPWM_1_backup.PWMControlRegister);
            #endif /* (GLCDPWM_1_UseControl) */
        #endif  /* (!GLCDPWM_1_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: GLCDPWM_1_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_1_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void GLCDPWM_1_Sleep(void) 
{
    #if(GLCDPWM_1_UseControl)
        if(GLCDPWM_1_CTRL_ENABLE == (GLCDPWM_1_CONTROL & GLCDPWM_1_CTRL_ENABLE))
        {
            /*Component is enabled */
            GLCDPWM_1_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            GLCDPWM_1_backup.PWMEnableState = 0u;
        }
    #endif /* (GLCDPWM_1_UseControl) */

    /* Stop component */
    GLCDPWM_1_Stop();

    /* Save registers configuration */
    GLCDPWM_1_SaveConfig();
}


/*******************************************************************************
* Function Name: GLCDPWM_1_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  GLCDPWM_1_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void GLCDPWM_1_Wakeup(void) 
{
     /* Restore registers values */
    GLCDPWM_1_RestoreConfig();

    if(GLCDPWM_1_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        GLCDPWM_1_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
